@@ -32,7 +32,7 @@ class Scatterpolargl(BaseTraceType):
         """
         Assigns extra data each datum. This may be useful when
         listening to hover, click and selection events. Note that,
-        *scatter* traces also appends customdata items in the markers
+        "scatter" traces also appends customdata items in the markers
         DOM elements
     
         The 'customdata' property is an array that may be specified as a tuple,
@@ -68,23 +68,65 @@ class Scatterpolargl(BaseTraceType):
     def customdatasrc(self, val):
         self['customdatasrc'] = val
 
+    # dr
+    # --
+    @property
+    def dr(self):
+        """
+        Sets the r coordinate step.
+    
+        The 'dr' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self['dr']
+
+    @dr.setter
+    def dr(self, val):
+        self['dr'] = val
+
+    # dtheta
+    # ------
+    @property
+    def dtheta(self):
+        """
+        Sets the theta coordinate step. By default, the `dtheta` step
+        equals the subplot's period divided by the length of the `r`
+        coordinates.
+    
+        The 'dtheta' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self['dtheta']
+
+    @dtheta.setter
+    def dtheta(self, val):
+        self['dtheta'] = val
+
     # fill
     # ----
     @property
     def fill(self):
         """
         Sets the area to fill with a solid color. Use with `fillcolor`
-        if not *none*. *tozerox* and *tozeroy* fill to x=0 and y=0
-        respectively. *tonextx* and *tonexty* fill between the
+        if not "none". "tozerox" and "tozeroy" fill to x=0 and y=0
+        respectively. "tonextx" and "tonexty" fill between the
         endpoints of this trace and the endpoints of the trace before
         it, connecting those endpoints with straight lines (to make a
         stacked area graph); if there is no trace before it, they
-        behave like *tozerox* and *tozeroy*. *toself* connects the
+        behave like "tozerox" and "tozeroy". "toself" connects the
         endpoints of the trace (or each segment of the trace if it has
-        gaps) into a closed shape. *tonext* fills the space between two
+        gaps) into a closed shape. "tonext" fills the space between two
         traces if one completely encloses the other (eg consecutive
-        contour lines), and behaves like *toself* if there is no trace
-        before it. *tonext* should not be used if one trace does not
+        contour lines), and behaves like "toself" if there is no trace
+        before it. "tonext" should not be used if one trace does not
         enclose the other.
     
         The 'fill' property is an enumeration that may be specified as:
@@ -259,30 +301,51 @@ class Scatterpolargl(BaseTraceType):
     def hoverlabel(self, val):
         self['hoverlabel'] = val
 
-    # hoveron
-    # -------
+    # hovertext
+    # ---------
     @property
-    def hoveron(self):
+    def hovertext(self):
         """
-        Do the hover effects highlight individual points (markers or
-        line points) or do they highlight filled regions? If the fill
-        is *toself* or *tonext* and there are no markers or text, then
-        the default is *fills*, otherwise it is *points*.
+        Sets hover text elements associated with each (x,y) pair. If a
+        single string, the same string appears over all the data
+        points. If an array of string, the items are mapped in order to
+        the this trace's (x,y) coordinates. To be seen, trace
+        `hoverinfo` must contain a "text" flag.
     
-        The 'hoveron' property is a flaglist and may be specified
-        as a string containing:
-          - Any combination of ['points', 'fills'] joined with '+' characters
-            (e.g. 'points+fills')
+        The 'hovertext' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+          - A tuple, list, or one-dimensional numpy array of the above
 
         Returns
         -------
-        Any
+        str|numpy.ndarray
         """
-        return self['hoveron']
+        return self['hovertext']
 
-    @hoveron.setter
-    def hoveron(self, val):
-        self['hoveron'] = val
+    @hovertext.setter
+    def hovertext(self, val):
+        self['hovertext'] = val
+
+    # hovertextsrc
+    # ------------
+    @property
+    def hovertextsrc(self):
+        """
+        Sets the source reference on plot.ly for  hovertext .
+    
+        The 'hovertextsrc' property must be specified as a string or
+        as a plotly.grid_objs.Column object
+
+        Returns
+        -------
+        str
+        """
+        return self['hovertextsrc']
+
+    @hovertextsrc.setter
+    def hovertextsrc(self, val):
+        self['hovertextsrc'] = val
 
     # ids
     # ---
@@ -489,11 +552,11 @@ class Scatterpolargl(BaseTraceType):
                     .
                 symbol
                     Sets the marker symbol type. Adding 100 is
-                    equivalent to appending *-open* to a symbol
+                    equivalent to appending "-open" to a symbol
                     name. Adding 200 is equivalent to appending
-                    *-dot* to a symbol name. Adding 300 is
-                    equivalent to appending *-open-dot* or *dot-
-                    open* to a symbol name.
+                    "-dot" to a symbol name. Adding 300 is
+                    equivalent to appending "-open-dot" or "dot-
+                    open" to a symbol name.
                 symbolsrc
                     Sets the source reference on plot.ly for
                     symbol .
@@ -514,10 +577,10 @@ class Scatterpolargl(BaseTraceType):
     def mode(self):
         """
         Determines the drawing mode for this scatter trace. If the
-        provided `mode` includes *text* then the `text` elements appear
+        provided `mode` includes "text" then the `text` elements appear
         at the coordinates. Otherwise, the `text` elements appear on
         hover. If there are less than 20 points, then the default is
-        *lines+markers*. Otherwise, *lines*.
+        "lines+markers". Otherwise, "lines".
     
         The 'mode' property is a flaglist and may be specified
         as a string containing:
@@ -597,6 +660,27 @@ class Scatterpolargl(BaseTraceType):
     def r(self, val):
         self['r'] = val
 
+    # r0
+    # --
+    @property
+    def r0(self):
+        """
+        Alternate to `r`. Builds a linear space of r coordinates. Use
+        with `dr` where `r0` is the starting coordinate and `dr` the
+        step.
+    
+        The 'r0' property accepts values of any type
+
+        Returns
+        -------
+        Any
+        """
+        return self['r0']
+
+    @r0.setter
+    def r0(self, val):
+        self['r0'] = val
+
     # rsrc
     # ----
     @property
@@ -708,7 +792,7 @@ class Scatterpolargl(BaseTraceType):
                 maxpoints
                     Sets the maximum number of points to keep on
                     the plots from an incoming stream. If
-                    `maxpoints` is set to *50*, only the newest 50
+                    `maxpoints` is set to 50, only the newest 50
                     points will be displayed on the plot.
                 token
                     The stream id number links a data trace on a
@@ -731,8 +815,8 @@ class Scatterpolargl(BaseTraceType):
     def subplot(self):
         """
         Sets a reference between this trace's data coordinates and a
-        polar subplot. If *polar* (the default value), the data refer
-        to `layout.polar`. If *polar2*, the data refer to
+        polar subplot. If "polar" (the default value), the data refer
+        to `layout.polar`. If "polar2", the data refer to
         `layout.polar2`, and so on.
     
         The 'subplot' property is an identifier of a particular
@@ -759,7 +843,7 @@ class Scatterpolargl(BaseTraceType):
         string, the same string appears over all the data points. If an
         array of string, the items are mapped in order to the this
         trace's (x,y) coordinates. If trace `hoverinfo` contains a
-        *text* flag and *hovertext* is not set, these elements will be
+        "text" flag and "hovertext" is not set, these elements will be
         seen in the hover labels.
     
         The 'text' property is a string and must be specified as:
@@ -777,6 +861,106 @@ class Scatterpolargl(BaseTraceType):
     def text(self, val):
         self['text'] = val
 
+    # textfont
+    # --------
+    @property
+    def textfont(self):
+        """
+        Sets the text font.
+    
+        The 'textfont' property is an instance of Textfont
+        that may be specified as:
+          - An instance of plotly.graph_objs.scatterpolargl.Textfont
+          - A dict of string/value properties that will be passed
+            to the Textfont constructor
+    
+            Supported dict properties:
+                
+                color
+    
+                colorsrc
+                    Sets the source reference on plot.ly for  color
+                    .
+                family
+                    HTML font family - the typeface that will be
+                    applied by the web browser. The web browser
+                    will only be able to apply a font if it is
+                    available on the system which it operates.
+                    Provide multiple font families, separated by
+                    commas, to indicate the preference in which to
+                    apply fonts if they aren't available on the
+                    system. The plotly service (at https://plot.ly
+                    or on-premise) generates images on a server,
+                    where only a select number of fonts are
+                    installed and supported. These include "Arial",
+                    "Balto", "Courier New", "Droid Sans",, "Droid
+                    Serif", "Droid Sans Mono", "Gravitas One", "Old
+                    Standard TT", "Open Sans", "Overpass", "PT Sans
+                    Narrow", "Raleway", "Times New Roman".
+                familysrc
+                    Sets the source reference on plot.ly for
+                    family .
+                size
+    
+                sizesrc
+                    Sets the source reference on plot.ly for  size
+                    .
+
+        Returns
+        -------
+        plotly.graph_objs.scatterpolargl.Textfont
+        """
+        return self['textfont']
+
+    @textfont.setter
+    def textfont(self, val):
+        self['textfont'] = val
+
+    # textposition
+    # ------------
+    @property
+    def textposition(self):
+        """
+        Sets the positions of the `text` elements with respects to the
+        (x,y) coordinates.
+    
+        The 'textposition' property is an enumeration that may be specified as:
+          - One of the following enumeration values:
+                ['top left', 'top center', 'top right', 'middle left',
+                'middle center', 'middle right', 'bottom left', 'bottom
+                center', 'bottom right']
+          - A tuple, list, or one-dimensional numpy array of the above
+
+        Returns
+        -------
+        Any|numpy.ndarray
+        """
+        return self['textposition']
+
+    @textposition.setter
+    def textposition(self, val):
+        self['textposition'] = val
+
+    # textpositionsrc
+    # ---------------
+    @property
+    def textpositionsrc(self):
+        """
+        Sets the source reference on plot.ly for  textposition .
+    
+        The 'textpositionsrc' property must be specified as a string or
+        as a plotly.grid_objs.Column object
+
+        Returns
+        -------
+        str
+        """
+        return self['textpositionsrc']
+
+    @textpositionsrc.setter
+    def textpositionsrc(self, val):
+        self['textpositionsrc'] = val
+
     # textsrc
     # -------
     @property
@@ -817,6 +1001,27 @@ class Scatterpolargl(BaseTraceType):
     def theta(self, val):
         self['theta'] = val
 
+    # theta0
+    # ------
+    @property
+    def theta0(self):
+        """
+        Alternate to `theta`. Builds a linear space of theta
+        coordinates. Use with `dtheta` where `theta0` is the starting
+        coordinate and `dtheta` the step.
+    
+        The 'theta0' property accepts values of any type
+
+        Returns
+        -------
+        Any
+        """
+        return self['theta0']
+
+    @theta0.setter
+    def theta0(self, val):
+        self['theta0'] = val
+
     # thetasrc
     # --------
     @property
@@ -842,8 +1047,8 @@ class Scatterpolargl(BaseTraceType):
     @property
     def thetaunit(self):
         """
-        Sets the unit of input *theta* values. Has an effect only when
-        on *linear* angular axes.
+        Sets the unit of input "theta" values. Has an effect only when
+        on "linear" angular axes.
     
         The 'thetaunit' property is an enumeration that may be specified as:
           - One of the following enumeration values:
@@ -915,7 +1120,7 @@ class Scatterpolargl(BaseTraceType):
     def visible(self):
         """
         Determines whether or not this trace is visible. If
-        *legendonly*, the trace is not drawn, but can appear as a
+        "legendonly", the trace is not drawn, but can appear as a
         legend item (provided that the legend itself is visible).
     
         The 'visible' property is an enumeration that may be specified as:
@@ -955,24 +1160,30 @@ class Scatterpolargl(BaseTraceType):
         customdata
             Assigns extra data each datum. This may be useful when
             listening to hover, click and selection events. Note
-            that, *scatter* traces also appends customdata items in
+            that, "scatter" traces also appends customdata items in
             the markers DOM elements
         customdatasrc
             Sets the source reference on plot.ly for  customdata .
+        dr
+            Sets the r coordinate step.
+        dtheta
+            Sets the theta coordinate step. By default, the
+            `dtheta` step equals the subplot's period divided by
+            the length of the `r` coordinates.
         fill
             Sets the area to fill with a solid color. Use with
-            `fillcolor` if not *none*. *tozerox* and *tozeroy* fill
-            to x=0 and y=0 respectively. *tonextx* and *tonexty*
+            `fillcolor` if not "none". "tozerox" and "tozeroy" fill
+            to x=0 and y=0 respectively. "tonextx" and "tonexty"
             fill between the endpoints of this trace and the
             endpoints of the trace before it, connecting those
             endpoints with straight lines (to make a stacked area
             graph); if there is no trace before it, they behave
-            like *tozerox* and *tozeroy*. *toself* connects the
+            like "tozerox" and "tozeroy". "toself" connects the
             endpoints of the trace (or each segment of the trace if
-            it has gaps) into a closed shape. *tonext* fills the
+            it has gaps) into a closed shape. "tonext" fills the
             space between two traces if one completely encloses the
             other (eg consecutive contour lines), and behaves like
-            *toself* if there is no trace before it. *tonext*
+            "toself" if there is no trace before it. "tonext"
             should not be used if one trace does not enclose the
             other.
         fillcolor
@@ -989,12 +1200,15 @@ class Scatterpolargl(BaseTraceType):
         hoverlabel
             plotly.graph_objs.scatterpolargl.Hoverlabel instance or
             dict with compatible properties
-        hoveron
-            Do the hover effects highlight individual points
-            (markers or line points) or do they highlight filled
-            regions? If the fill is *toself* or *tonext* and there
-            are no markers or text, then the default is *fills*,
-            otherwise it is *points*.
+        hovertext
+            Sets hover text elements associated with each (x,y)
+            pair. If a single string, the same string appears over
+            all the data points. If an array of string, the items
+            are mapped in order to the this trace's (x,y)
+            coordinates. To be seen, trace `hoverinfo` must contain
+            a "text" flag.
+        hovertextsrc
+            Sets the source reference on plot.ly for  hovertext .
         ids
             Assigns id labels to each datum. These ids for object
             constancy of data points during animation. Should be an
@@ -1013,11 +1227,11 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         mode
             Determines the drawing mode for this scatter trace. If
-            the provided `mode` includes *text* then the `text`
+            the provided `mode` includes "text" then the `text`
             elements appear at the coordinates. Otherwise, the
             `text` elements appear on hover. If there are less than
-            20 points, then the default is *lines+markers*.
-            Otherwise, *lines*.
+            20 points, then the default is "lines+markers".
+            Otherwise, "lines".
         name
             Sets the trace name. The trace name appear as the
             legend item and on hover.
@@ -1025,6 +1239,10 @@ class Scatterpolargl(BaseTraceType):
             Sets the opacity of the trace.
         r
             Sets the radial coordinates
+        r0
+            Alternate to `r`. Builds a linear space of r
+            coordinates. Use with `dr` where `r0` is the starting
+            coordinate and `dr` the step.
         rsrc
             Sets the source reference on plot.ly for  r .
         selected
@@ -1045,26 +1263,38 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         subplot
             Sets a reference between this trace's data coordinates
-            and a polar subplot. If *polar* (the default value),
-            the data refer to `layout.polar`. If *polar2*, the data
+            and a polar subplot. If "polar" (the default value),
+            the data refer to `layout.polar`. If "polar2", the data
             refer to `layout.polar2`, and so on.
         text
             Sets text elements associated with each (x,y) pair. If
             a single string, the same string appears over all the
             data points. If an array of string, the items are
             mapped in order to the this trace's (x,y) coordinates.
-            If trace `hoverinfo` contains a *text* flag and
-            *hovertext* is not set, these elements will be seen in
+            If trace `hoverinfo` contains a "text" flag and
+            "hovertext" is not set, these elements will be seen in
             the hover labels.
+        textfont
+            Sets the text font.
+        textposition
+            Sets the positions of the `text` elements with respects
+            to the (x,y) coordinates.
+        textpositionsrc
+            Sets the source reference on plot.ly for  textposition
+            .
         textsrc
             Sets the source reference on plot.ly for  text .
         theta
             Sets the angular coordinates
+        theta0
+            Alternate to `theta`. Builds a linear space of theta
+            coordinates. Use with `dtheta` where `theta0` is the
+            starting coordinate and `dtheta` the step.
         thetasrc
             Sets the source reference on plot.ly for  theta .
         thetaunit
-            Sets the unit of input *theta* values. Has an effect
-            only when on *linear* angular axes.
+            Sets the unit of input "theta" values. Has an effect
+            only when on "linear" angular axes.
         uid
 
         unselected
@@ -1072,7 +1302,7 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         visible
             Determines whether or not this trace is visible. If
-            *legendonly*, the trace is not drawn, but can appear as
+            "legendonly", the trace is not drawn, but can appear as
             a legend item (provided that the legend itself is
             visible).
         """
@@ -1083,12 +1313,15 @@ class Scatterpolargl(BaseTraceType):
         connectgaps=None,
         customdata=None,
         customdatasrc=None,
+        dr=None,
+        dtheta=None,
         fill=None,
         fillcolor=None,
         hoverinfo=None,
         hoverinfosrc=None,
         hoverlabel=None,
-        hoveron=None,
+        hovertext=None,
+        hovertextsrc=None,
         ids=None,
         idssrc=None,
         legendgroup=None,
@@ -1098,6 +1331,7 @@ class Scatterpolargl(BaseTraceType):
         name=None,
         opacity=None,
         r=None,
+        r0=None,
         rsrc=None,
         selected=None,
         selectedpoints=None,
@@ -1105,8 +1339,12 @@ class Scatterpolargl(BaseTraceType):
         stream=None,
         subplot=None,
         text=None,
+        textfont=None,
+        textposition=None,
+        textpositionsrc=None,
         textsrc=None,
         theta=None,
+        theta0=None,
         thetasrc=None,
         thetaunit=None,
         uid=None,
@@ -1135,24 +1373,30 @@ class Scatterpolargl(BaseTraceType):
         customdata
             Assigns extra data each datum. This may be useful when
             listening to hover, click and selection events. Note
-            that, *scatter* traces also appends customdata items in
+            that, "scatter" traces also appends customdata items in
             the markers DOM elements
         customdatasrc
             Sets the source reference on plot.ly for  customdata .
+        dr
+            Sets the r coordinate step.
+        dtheta
+            Sets the theta coordinate step. By default, the
+            `dtheta` step equals the subplot's period divided by
+            the length of the `r` coordinates.
         fill
             Sets the area to fill with a solid color. Use with
-            `fillcolor` if not *none*. *tozerox* and *tozeroy* fill
-            to x=0 and y=0 respectively. *tonextx* and *tonexty*
+            `fillcolor` if not "none". "tozerox" and "tozeroy" fill
+            to x=0 and y=0 respectively. "tonextx" and "tonexty"
             fill between the endpoints of this trace and the
             endpoints of the trace before it, connecting those
             endpoints with straight lines (to make a stacked area
             graph); if there is no trace before it, they behave
-            like *tozerox* and *tozeroy*. *toself* connects the
+            like "tozerox" and "tozeroy". "toself" connects the
             endpoints of the trace (or each segment of the trace if
-            it has gaps) into a closed shape. *tonext* fills the
+            it has gaps) into a closed shape. "tonext" fills the
             space between two traces if one completely encloses the
             other (eg consecutive contour lines), and behaves like
-            *toself* if there is no trace before it. *tonext*
+            "toself" if there is no trace before it. "tonext"
             should not be used if one trace does not enclose the
             other.
         fillcolor
@@ -1169,12 +1413,15 @@ class Scatterpolargl(BaseTraceType):
         hoverlabel
             plotly.graph_objs.scatterpolargl.Hoverlabel instance or
             dict with compatible properties
-        hoveron
-            Do the hover effects highlight individual points
-            (markers or line points) or do they highlight filled
-            regions? If the fill is *toself* or *tonext* and there
-            are no markers or text, then the default is *fills*,
-            otherwise it is *points*.
+        hovertext
+            Sets hover text elements associated with each (x,y)
+            pair. If a single string, the same string appears over
+            all the data points. If an array of string, the items
+            are mapped in order to the this trace's (x,y)
+            coordinates. To be seen, trace `hoverinfo` must contain
+            a "text" flag.
+        hovertextsrc
+            Sets the source reference on plot.ly for  hovertext .
         ids
             Assigns id labels to each datum. These ids for object
             constancy of data points during animation. Should be an
@@ -1193,11 +1440,11 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         mode
             Determines the drawing mode for this scatter trace. If
-            the provided `mode` includes *text* then the `text`
+            the provided `mode` includes "text" then the `text`
             elements appear at the coordinates. Otherwise, the
             `text` elements appear on hover. If there are less than
-            20 points, then the default is *lines+markers*.
-            Otherwise, *lines*.
+            20 points, then the default is "lines+markers".
+            Otherwise, "lines".
         name
             Sets the trace name. The trace name appear as the
             legend item and on hover.
@@ -1205,6 +1452,10 @@ class Scatterpolargl(BaseTraceType):
             Sets the opacity of the trace.
         r
             Sets the radial coordinates
+        r0
+            Alternate to `r`. Builds a linear space of r
+            coordinates. Use with `dr` where `r0` is the starting
+            coordinate and `dr` the step.
         rsrc
             Sets the source reference on plot.ly for  r .
         selected
@@ -1225,26 +1476,38 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         subplot
             Sets a reference between this trace's data coordinates
-            and a polar subplot. If *polar* (the default value),
-            the data refer to `layout.polar`. If *polar2*, the data
+            and a polar subplot. If "polar" (the default value),
+            the data refer to `layout.polar`. If "polar2", the data
             refer to `layout.polar2`, and so on.
         text
             Sets text elements associated with each (x,y) pair. If
             a single string, the same string appears over all the
             data points. If an array of string, the items are
             mapped in order to the this trace's (x,y) coordinates.
-            If trace `hoverinfo` contains a *text* flag and
-            *hovertext* is not set, these elements will be seen in
+            If trace `hoverinfo` contains a "text" flag and
+            "hovertext" is not set, these elements will be seen in
             the hover labels.
+        textfont
+            Sets the text font.
+        textposition
+            Sets the positions of the `text` elements with respects
+            to the (x,y) coordinates.
+        textpositionsrc
+            Sets the source reference on plot.ly for  textposition
+            .
         textsrc
             Sets the source reference on plot.ly for  text .
         theta
             Sets the angular coordinates
+        theta0
+            Alternate to `theta`. Builds a linear space of theta
+            coordinates. Use with `dtheta` where `theta0` is the
+            starting coordinate and `dtheta` the step.
         thetasrc
             Sets the source reference on plot.ly for  theta .
         thetaunit
-            Sets the unit of input *theta* values. Has an effect
-            only when on *linear* angular axes.
+            Sets the unit of input "theta" values. Has an effect
+            only when on "linear" angular axes.
         uid
 
         unselected
@@ -1252,7 +1515,7 @@ class Scatterpolargl(BaseTraceType):
             dict with compatible properties
         visible
             Determines whether or not this trace is visible. If
-            *legendonly*, the trace is not drawn, but can appear as
+            "legendonly", the trace is not drawn, but can appear as
             a legend item (provided that the legend itself is
             visible).
 
@@ -1278,6 +1541,10 @@ constructor must be a dict or
 an instance of plotly.graph_objs.Scatterpolargl"""
             )
 
+        # Handle skip_invalid
+        # -------------------
+        self._skip_invalid = kwargs.pop('skip_invalid', False)
+
         # Import validators
         # -----------------
         from plotly.validators import (scatterpolargl as v_scatterpolargl)
@@ -1289,13 +1556,17 @@ an instance of plotly.graph_objs.Scatterpolargl"""
         self._validators['customdata'] = v_scatterpolargl.CustomdataValidator()
         self._validators['customdatasrc'
                         ] = v_scatterpolargl.CustomdatasrcValidator()
+        self._validators['dr'] = v_scatterpolargl.DrValidator()
+        self._validators['dtheta'] = v_scatterpolargl.DthetaValidator()
         self._validators['fill'] = v_scatterpolargl.FillValidator()
         self._validators['fillcolor'] = v_scatterpolargl.FillcolorValidator()
         self._validators['hoverinfo'] = v_scatterpolargl.HoverinfoValidator()
         self._validators['hoverinfosrc'
                         ] = v_scatterpolargl.HoverinfosrcValidator()
         self._validators['hoverlabel'] = v_scatterpolargl.HoverlabelValidator()
-        self._validators['hoveron'] = v_scatterpolargl.HoveronValidator()
+        self._validators['hovertext'] = v_scatterpolargl.HovertextValidator()
+        self._validators['hovertextsrc'
+                        ] = v_scatterpolargl.HovertextsrcValidator()
         self._validators['ids'] = v_scatterpolargl.IdsValidator()
         self._validators['idssrc'] = v_scatterpolargl.IdssrcValidator()
         self._validators['legendgroup'
@@ -1306,6 +1577,7 @@ an instance of plotly.graph_objs.Scatterpolargl"""
         self._validators['name'] = v_scatterpolargl.NameValidator()
         self._validators['opacity'] = v_scatterpolargl.OpacityValidator()
         self._validators['r'] = v_scatterpolargl.RValidator()
+        self._validators['r0'] = v_scatterpolargl.R0Validator()
         self._validators['rsrc'] = v_scatterpolargl.RsrcValidator()
         self._validators['selected'] = v_scatterpolargl.SelectedValidator()
         self._validators['selectedpoints'
@@ -1314,8 +1586,14 @@ an instance of plotly.graph_objs.Scatterpolargl"""
         self._validators['stream'] = v_scatterpolargl.StreamValidator()
         self._validators['subplot'] = v_scatterpolargl.SubplotValidator()
         self._validators['text'] = v_scatterpolargl.TextValidator()
+        self._validators['textfont'] = v_scatterpolargl.TextfontValidator()
+        self._validators['textposition'
+                        ] = v_scatterpolargl.TextpositionValidator()
+        self._validators['textpositionsrc'
+                        ] = v_scatterpolargl.TextpositionsrcValidator()
         self._validators['textsrc'] = v_scatterpolargl.TextsrcValidator()
         self._validators['theta'] = v_scatterpolargl.ThetaValidator()
+        self._validators['theta0'] = v_scatterpolargl.Theta0Validator()
         self._validators['thetasrc'] = v_scatterpolargl.ThetasrcValidator()
         self._validators['thetaunit'] = v_scatterpolargl.ThetaunitValidator()
         self._validators['uid'] = v_scatterpolargl.UidValidator()
@@ -1325,69 +1603,88 @@ an instance of plotly.graph_objs.Scatterpolargl"""
         # Populate data dict with properties
         # ----------------------------------
         _v = arg.pop('connectgaps', None)
-        self.connectgaps = connectgaps if connectgaps is not None else _v
+        self['connectgaps'] = connectgaps if connectgaps is not None else _v
         _v = arg.pop('customdata', None)
-        self.customdata = customdata if customdata is not None else _v
+        self['customdata'] = customdata if customdata is not None else _v
         _v = arg.pop('customdatasrc', None)
-        self.customdatasrc = customdatasrc if customdatasrc is not None else _v
+        self['customdatasrc'
+            ] = customdatasrc if customdatasrc is not None else _v
+        _v = arg.pop('dr', None)
+        self['dr'] = dr if dr is not None else _v
+        _v = arg.pop('dtheta', None)
+        self['dtheta'] = dtheta if dtheta is not None else _v
         _v = arg.pop('fill', None)
-        self.fill = fill if fill is not None else _v
+        self['fill'] = fill if fill is not None else _v
         _v = arg.pop('fillcolor', None)
-        self.fillcolor = fillcolor if fillcolor is not None else _v
+        self['fillcolor'] = fillcolor if fillcolor is not None else _v
         _v = arg.pop('hoverinfo', None)
-        self.hoverinfo = hoverinfo if hoverinfo is not None else _v
+        self['hoverinfo'] = hoverinfo if hoverinfo is not None else _v
         _v = arg.pop('hoverinfosrc', None)
-        self.hoverinfosrc = hoverinfosrc if hoverinfosrc is not None else _v
+        self['hoverinfosrc'] = hoverinfosrc if hoverinfosrc is not None else _v
         _v = arg.pop('hoverlabel', None)
-        self.hoverlabel = hoverlabel if hoverlabel is not None else _v
-        _v = arg.pop('hoveron', None)
-        self.hoveron = hoveron if hoveron is not None else _v
+        self['hoverlabel'] = hoverlabel if hoverlabel is not None else _v
+        _v = arg.pop('hovertext', None)
+        self['hovertext'] = hovertext if hovertext is not None else _v
+        _v = arg.pop('hovertextsrc', None)
+        self['hovertextsrc'] = hovertextsrc if hovertextsrc is not None else _v
         _v = arg.pop('ids', None)
-        self.ids = ids if ids is not None else _v
+        self['ids'] = ids if ids is not None else _v
         _v = arg.pop('idssrc', None)
-        self.idssrc = idssrc if idssrc is not None else _v
+        self['idssrc'] = idssrc if idssrc is not None else _v
         _v = arg.pop('legendgroup', None)
-        self.legendgroup = legendgroup if legendgroup is not None else _v
+        self['legendgroup'] = legendgroup if legendgroup is not None else _v
         _v = arg.pop('line', None)
-        self.line = line if line is not None else _v
+        self['line'] = line if line is not None else _v
         _v = arg.pop('marker', None)
-        self.marker = marker if marker is not None else _v
+        self['marker'] = marker if marker is not None else _v
         _v = arg.pop('mode', None)
-        self.mode = mode if mode is not None else _v
+        self['mode'] = mode if mode is not None else _v
         _v = arg.pop('name', None)
-        self.name = name if name is not None else _v
+        self['name'] = name if name is not None else _v
         _v = arg.pop('opacity', None)
-        self.opacity = opacity if opacity is not None else _v
+        self['opacity'] = opacity if opacity is not None else _v
         _v = arg.pop('r', None)
-        self.r = r if r is not None else _v
+        self['r'] = r if r is not None else _v
+        _v = arg.pop('r0', None)
+        self['r0'] = r0 if r0 is not None else _v
         _v = arg.pop('rsrc', None)
-        self.rsrc = rsrc if rsrc is not None else _v
+        self['rsrc'] = rsrc if rsrc is not None else _v
         _v = arg.pop('selected', None)
-        self.selected = selected if selected is not None else _v
+        self['selected'] = selected if selected is not None else _v
         _v = arg.pop('selectedpoints', None)
-        self.selectedpoints = selectedpoints if selectedpoints is not None else _v
+        self['selectedpoints'
+            ] = selectedpoints if selectedpoints is not None else _v
         _v = arg.pop('showlegend', None)
-        self.showlegend = showlegend if showlegend is not None else _v
+        self['showlegend'] = showlegend if showlegend is not None else _v
         _v = arg.pop('stream', None)
-        self.stream = stream if stream is not None else _v
+        self['stream'] = stream if stream is not None else _v
         _v = arg.pop('subplot', None)
-        self.subplot = subplot if subplot is not None else _v
+        self['subplot'] = subplot if subplot is not None else _v
         _v = arg.pop('text', None)
-        self.text = text if text is not None else _v
+        self['text'] = text if text is not None else _v
+        _v = arg.pop('textfont', None)
+        self['textfont'] = textfont if textfont is not None else _v
+        _v = arg.pop('textposition', None)
+        self['textposition'] = textposition if textposition is not None else _v
+        _v = arg.pop('textpositionsrc', None)
+        self['textpositionsrc'
+            ] = textpositionsrc if textpositionsrc is not None else _v
         _v = arg.pop('textsrc', None)
-        self.textsrc = textsrc if textsrc is not None else _v
+        self['textsrc'] = textsrc if textsrc is not None else _v
         _v = arg.pop('theta', None)
-        self.theta = theta if theta is not None else _v
+        self['theta'] = theta if theta is not None else _v
+        _v = arg.pop('theta0', None)
+        self['theta0'] = theta0 if theta0 is not None else _v
         _v = arg.pop('thetasrc', None)
-        self.thetasrc = thetasrc if thetasrc is not None else _v
+        self['thetasrc'] = thetasrc if thetasrc is not None else _v
         _v = arg.pop('thetaunit', None)
-        self.thetaunit = thetaunit if thetaunit is not None else _v
+        self['thetaunit'] = thetaunit if thetaunit is not None else _v
         _v = arg.pop('uid', None)
-        self.uid = uid if uid is not None else _v
+        self['uid'] = uid if uid is not None else _v
         _v = arg.pop('unselected', None)
-        self.unselected = unselected if unselected is not None else _v
+        self['unselected'] = unselected if unselected is not None else _v
         _v = arg.pop('visible', None)
-        self.visible = visible if visible is not None else _v
+        self['visible'] = visible if visible is not None else _v
 
         # Read-only literals
         # ------------------
@@ -1402,3 +1699,7 @@ an instance of plotly.graph_objs.Scatterpolargl"""
         # Process unknown kwargs
         # ----------------------
         self._process_kwargs(**dict(arg, **kwargs))
+
+        # Reset skip_invalid
+        # ------------------
+        self._skip_invalid = False
