@@ -291,11 +291,11 @@ class Slider(BaseLayoutHierarchyType):
                     system. The plotly service (at https://plot.ly
                     or on-premise) generates images on a server,
                     where only a select number of fonts are
-                    installed and supported. These include *Arial*,
-                    *Balto*, *Courier New*, *Droid Sans*,, *Droid
-                    Serif*, *Droid Sans Mono*, *Gravitas One*, *Old
-                    Standard TT*, *Open Sans*, *Overpass*, *PT Sans
-                    Narrow*, *Raleway*, *Times New Roman*.
+                    installed and supported. These include "Arial",
+                    "Balto", "Courier New", "Droid Sans",, "Droid
+                    Serif", "Droid Sans Mono", "Gravitas One", "Old
+                    Standard TT", "Open Sans", "Overpass", "PT Sans
+                    Narrow", "Raleway", "Times New Roman".
                 size
 
         Returns
@@ -336,7 +336,7 @@ class Slider(BaseLayoutHierarchyType):
     def lenmode(self):
         """
         Determines whether this slider length is set in units of plot
-        *fraction* or in *pixels. Use `len` to set the value.
+        "fraction" or in *pixels. Use `len` to set the value.
     
         The 'lenmode' property is an enumeration that may be specified as:
           - One of the following enumeration values:
@@ -714,7 +714,7 @@ class Slider(BaseLayoutHierarchyType):
     def xanchor(self):
         """
         Sets the slider's horizontal position anchor. This anchor binds
-        the `x` position to the *left*, *center* or *right* of the
+        the `x` position to the "left", "center" or "right" of the
         range selector.
     
         The 'xanchor' property is an enumeration that may be specified as:
@@ -757,7 +757,7 @@ class Slider(BaseLayoutHierarchyType):
     def yanchor(self):
         """
         Sets the slider's vertical position anchor This anchor binds
-        the `y` position to the *top*, *middle* or *bottom* of the
+        the `y` position to the "top", "middle" or "bottom" of the
         range selector.
     
         The 'yanchor' property is an enumeration that may be specified as:
@@ -809,7 +809,7 @@ class Slider(BaseLayoutHierarchyType):
             this length minus the padding on both ends.
         lenmode
             Determines whether this slider length is set in units
-            of plot *fraction* or in *pixels. Use `len` to set the
+            of plot "fraction" or in *pixels. Use `len` to set the
             value.
         minorticklen
             Sets the length in pixels of minor step tick marks
@@ -854,15 +854,15 @@ class Slider(BaseLayoutHierarchyType):
             slider.
         xanchor
             Sets the slider's horizontal position anchor. This
-            anchor binds the `x` position to the *left*, *center*
-            or *right* of the range selector.
+            anchor binds the `x` position to the "left", "center"
+            or "right" of the range selector.
         y
             Sets the y position (in normalized coordinates) of the
             slider.
         yanchor
             Sets the slider's vertical position anchor This anchor
-            binds the `y` position to the *top*, *middle* or
-            *bottom* of the range selector.
+            binds the `y` position to the "top", "middle" or
+            "bottom" of the range selector.
         """
 
     def __init__(
@@ -925,7 +925,7 @@ class Slider(BaseLayoutHierarchyType):
             this length minus the padding on both ends.
         lenmode
             Determines whether this slider length is set in units
-            of plot *fraction* or in *pixels. Use `len` to set the
+            of plot "fraction" or in *pixels. Use `len` to set the
             value.
         minorticklen
             Sets the length in pixels of minor step tick marks
@@ -970,15 +970,15 @@ class Slider(BaseLayoutHierarchyType):
             slider.
         xanchor
             Sets the slider's horizontal position anchor. This
-            anchor binds the `x` position to the *left*, *center*
-            or *right* of the range selector.
+            anchor binds the `x` position to the "left", "center"
+            or "right" of the range selector.
         y
             Sets the y position (in normalized coordinates) of the
             slider.
         yanchor
             Sets the slider's vertical position anchor This anchor
-            binds the `y` position to the *top*, *middle* or
-            *bottom* of the range selector.
+            binds the `y` position to the "top", "middle" or
+            "bottom" of the range selector.
 
         Returns
         -------
@@ -1002,6 +1002,10 @@ constructor must be a dict or
 an instance of plotly.graph_objs.layout.Slider"""
             )
 
+        # Handle skip_invalid
+        # -------------------
+        self._skip_invalid = kwargs.pop('skip_invalid', False)
+
         # Import validators
         # -----------------
         from plotly.validators.layout import (slider as v_slider)
@@ -1036,52 +1040,58 @@ an instance of plotly.graph_objs.layout.Slider"""
         # Populate data dict with properties
         # ----------------------------------
         _v = arg.pop('active', None)
-        self.active = active if active is not None else _v
+        self['active'] = active if active is not None else _v
         _v = arg.pop('activebgcolor', None)
-        self.activebgcolor = activebgcolor if activebgcolor is not None else _v
+        self['activebgcolor'
+            ] = activebgcolor if activebgcolor is not None else _v
         _v = arg.pop('bgcolor', None)
-        self.bgcolor = bgcolor if bgcolor is not None else _v
+        self['bgcolor'] = bgcolor if bgcolor is not None else _v
         _v = arg.pop('bordercolor', None)
-        self.bordercolor = bordercolor if bordercolor is not None else _v
+        self['bordercolor'] = bordercolor if bordercolor is not None else _v
         _v = arg.pop('borderwidth', None)
-        self.borderwidth = borderwidth if borderwidth is not None else _v
+        self['borderwidth'] = borderwidth if borderwidth is not None else _v
         _v = arg.pop('currentvalue', None)
-        self.currentvalue = currentvalue if currentvalue is not None else _v
+        self['currentvalue'] = currentvalue if currentvalue is not None else _v
         _v = arg.pop('font', None)
-        self.font = font if font is not None else _v
+        self['font'] = font if font is not None else _v
         _v = arg.pop('len', None)
-        self.len = len if len is not None else _v
+        self['len'] = len if len is not None else _v
         _v = arg.pop('lenmode', None)
-        self.lenmode = lenmode if lenmode is not None else _v
+        self['lenmode'] = lenmode if lenmode is not None else _v
         _v = arg.pop('minorticklen', None)
-        self.minorticklen = minorticklen if minorticklen is not None else _v
+        self['minorticklen'] = minorticklen if minorticklen is not None else _v
         _v = arg.pop('name', None)
-        self.name = name if name is not None else _v
+        self['name'] = name if name is not None else _v
         _v = arg.pop('pad', None)
-        self.pad = pad if pad is not None else _v
+        self['pad'] = pad if pad is not None else _v
         _v = arg.pop('steps', None)
-        self.steps = steps if steps is not None else _v
+        self['steps'] = steps if steps is not None else _v
         _v = arg.pop('templateitemname', None)
-        self.templateitemname = templateitemname if templateitemname is not None else _v
+        self['templateitemname'
+            ] = templateitemname if templateitemname is not None else _v
         _v = arg.pop('tickcolor', None)
-        self.tickcolor = tickcolor if tickcolor is not None else _v
+        self['tickcolor'] = tickcolor if tickcolor is not None else _v
         _v = arg.pop('ticklen', None)
-        self.ticklen = ticklen if ticklen is not None else _v
+        self['ticklen'] = ticklen if ticklen is not None else _v
         _v = arg.pop('tickwidth', None)
-        self.tickwidth = tickwidth if tickwidth is not None else _v
+        self['tickwidth'] = tickwidth if tickwidth is not None else _v
         _v = arg.pop('transition', None)
-        self.transition = transition if transition is not None else _v
+        self['transition'] = transition if transition is not None else _v
         _v = arg.pop('visible', None)
-        self.visible = visible if visible is not None else _v
+        self['visible'] = visible if visible is not None else _v
         _v = arg.pop('x', None)
-        self.x = x if x is not None else _v
+        self['x'] = x if x is not None else _v
         _v = arg.pop('xanchor', None)
-        self.xanchor = xanchor if xanchor is not None else _v
+        self['xanchor'] = xanchor if xanchor is not None else _v
         _v = arg.pop('y', None)
-        self.y = y if y is not None else _v
+        self['y'] = y if y is not None else _v
         _v = arg.pop('yanchor', None)
-        self.yanchor = yanchor if yanchor is not None else _v
+        self['yanchor'] = yanchor if yanchor is not None else _v
 
         # Process unknown kwargs
         # ----------------------
         self._process_kwargs(**dict(arg, **kwargs))
+
+        # Reset skip_invalid
+        # ------------------
+        self._skip_invalid = False
