@@ -7,7 +7,7 @@ class NotchedValidator(_plotly_utils.basevalidators.BooleanValidator):
         super(NotchedValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type='calcIfAutorange',
+            edit_type='calc',
             role='style',
             **kwargs
         )
