@@ -9,7 +9,7 @@ class TypeValidator(_plotly_utils.basevalidators.EnumeratedValidator):
         super(TypeValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type='calcIfAutorange+arraydraw',
+            edit_type='calc+arraydraw',
             role='info',
             values=['circle', 'rect', 'path', 'line'],
             **kwargs
