@@ -7,7 +7,7 @@ class Y0Validator(_plotly_utils.basevalidators.AnyValidator):
         super(Y0Validator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type='calcIfAutorange+arraydraw',
+            edit_type='calc+arraydraw',
             role='info',
             **kwargs
         )
