@@ -21,9 +21,10 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Determines whether or not the range of this
                 axis in the rangeslider use the same value than
                 in the main plot when zooming in/out. If
-                *auto*, the autorange will be used. If *fixed*,
-                the `range` is used. If *match*, the current
+                "auto", the autorange will be used. If "fixed",
+                the `range` is used. If "match", the current
                 range of the corresponding y-axis on the main
-                subplot is used.""",
+                subplot is used.
+""",
             **kwargs
         )
