@@ -7,7 +7,7 @@ class TickwidthValidator(_plotly_utils.basevalidators.NumberValidator):
         super(TickwidthValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type='calcIfAutorange',
+            edit_type='calc',
             max=0.5,
             min=0,
             role='style',
